==> phoenix_widgets-1.0.0.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'package:phoenix_widgets_example/phoenix_footer_page.dart';

import 'phoenix_card_page.dart';

void main() {
  runApp(const MyApp());
}

class MyApp extends StatefulWidget {
  const MyApp({Key? key}) : super(key: key);

  @override
  State<MyApp> createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return const MaterialApp(home: HomePage());
  }
}

class HomePage extends StatelessWidget {
  const HomePage({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      appBar: AppBar(
        title: const Text('Phoenix Widget Sample App'),
      ),
      body: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.all(16),
          child: Column(
            children: [
              ElevatedButton(
                onPressed: () {
                  Navigator.push(
                    context,
                    MaterialPageRoute(
                      builder: (context) => const PhoenixCardPage(),
                    ),
                  );
                },
                child: const SizedBox(
                  width: double.maxFinite,
                  child: Center(child: Text("Phoenix Card")),
                ),
              ),
              ElevatedButton(
                onPressed: () {
                  Navigator.push(
                    context,
                    MaterialPageRoute(
                      builder: (context) => const PhoenixFooterPage(),
                    ),
                  );
                },
                child: const SizedBox(
                  width: double.maxFinite,
                  child: Center(child: Text("Phoenix Footer")),
                ),
              )
            ],
          ),
        ),
      ),
    );
  }
}

==> phoenix_widgets-1.2.0.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'phoenix_bottom_menu_uhf_page.dart';
import 'phoenix_card_page.dart';
import 'phoenix_button_page.dart';

void main() {
  runApp(const MyApp());
}

class MyApp extends StatefulWidget {
  const MyApp({Key? key}) : super(key: key);

  @override
  State<MyApp> createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return const MaterialApp(home: HomePage());
  }
}

class HomePage extends StatelessWidget {
  const HomePage({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      appBar: AppBar(
        title: const Text('Phoenix Widget Sample App'),
      ),
      body: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.all(16),
          child: Column(
            children: [
              ElevatedButton(
                onPressed: () {
                  Navigator.push(
                    context,
                    MaterialPageRoute(
                      builder: (context) => const PhoenixCardPage(),
                    ),
                  );
                },
                child: const SizedBox(
                  width: double.maxFinite,
                  child: Center(child: Text("Phoenix Card")),
                ),
              ),
              ElevatedButton(
                onPressed: () {
                  Navigator.push(
                    context,
                    MaterialPageRoute(
                      builder: (context) => const PhoenixBottomMenuUHFPage(),
                    ),
                  );
                },
                child: const SizedBox(
                  width: double.maxFinite,
                  child: Center(child: Text("Phoenix Bottom Navigation UHF")),
                ),
              ),
              ElevatedButton(
                onPressed: () {
                  Navigator.push(
                    context,
                    MaterialPageRoute(
                      builder: (context) => const PhoenixButtonPage(),
                    ),
                  );
                },
                child: const SizedBox(
                  width: double.maxFinite,
                  child: Center(child: Text("Phoenix Button")),
                ),
              )
            ],
          ),
        ),
      ),
    );
  }
}
